/*****************************************************************************
/*
/*            INSTITUTO NACIONAL PARA LA EVALUACIN DE LA EDUCACIN
/*                       DIRECCIN DE PRUEBAS Y MEDICIN
/*                           SUBDIRECCION DE ANLISIS
/*_____________________________________________________________________________
/*
/*            EXAMENES DE LA CALIDAD Y EL LOGRO EDUCATIVOS (Excale)
/*                TERCER GRADO DE PRIMARIA (Excale 03)
/*
/*                          **** ESCRITURA ****
/*
/*                 Ciclo escolar evaluado: 2005 - 2006
/*_____________________________________________________________________________
/*
/*
/*    PROGRAMA PARA CONSTRUIR LA BASE DE DATOS DE ALUMNOS DE LA ASIGNATURA DE
/*                          ESCRITURA EN FORMATO SAS
/*
/*_____________________________________________________________________________
/*
/*  El programa convierte el archivo Excale03_2006_Alum_Esc.txt el cual est en
/*  formato ASCII a una base de datos en formato SAS. La sintxis realiza las
/*  siguientes tareas:
/*   - Declara formatos para algunas varibles
/*   - Lectura de variables del archivo en formato ASCII
/*   - Declara los valores perdidos por el usuario (missing values)
/*
/* INSTRUCCIONES
/*  Para construir la base de datos (tabla de datos) es necesario:
/*      1) Crear una carpeta de trabajo y colocar en ella al archivo Excale03_2006_Alum_Esc.txt
/*         as como el archivo Excale03_2006_Alum_Esc.SAS (este archivo) los cules se pueden
/*         descargar del sitio web del INEE.
/*      2) Modificar la primera y segunda lnea de los comandos de este archivo
/*         (libname y filename) para actualizar el nombre de la libreria y el archivo
/*         de trabajo.
/*      3) Ejecutar el programa del archivo.
/*
/*  Al finalizar, se crear la base de datos (tabla de datos) Excale03_2006_Alum_Esc.sas7bdat.
/*
/*  Posteriormente, cuando se desee utilizar nuevamente la base Excale03_2006_Alum_Esc.sas7bdat,
/*  se deber ejecutar primero el procedimiento FORMAT ("proc FORMAT") de este programa para que
/*  SAS carge los formatos necesarios para abrir la base.
/*
/* CONTACTO:
/*
/*      Para mayor informacin o aclaracin de dudas favor de contactar a la
/*      Subdireccin de Anlisis del Instituto
/*      Correo electrnico: excale.analisis@inee.edu.mx
/*      Tel 5482 0900 Ext. 1082
/*      Domicilio: Jos Ma. Velasco No. 101. 3er piso. Col. San Jos Insurgentes
/*                 Del. Benito Jurez. Mxico. D.F.
/*
/* FECHA DE ELABORACIN: 9 DE OCTUBRE DE 2007
/*
/*  ****************************************************************************/

LIBNAME  INEE  "C:\***\";
FILENAME alum "C:\***\Excale03_2006_Alum_Esc.TXT";

PROC FORMAT;
     VALUE id_entF     1         ="Aguascalientes"
                       2         ="Baja California"
                       3         ="Baja California Sur"
                       4         ="Campeche"
                       5         ="Coahuila"
                       6         ="Colima"
                       7         ="Chiapas"
                       8         ="Chihuahua"
                       9         ="Distrito Federal"
                       10        ="Durango"
                       11        ="Guanajuato"
                       12        ="Guerrero"
                       13        ="Hidalgo"
                       14        ="Jalisco"
                       15        ="Mxico"
                       16        ="Michoacn"
                       17        ="Morelos"
                       18        ="Nayarit"
                       19        ="Nuevo Len"
                       20        ="Oaxaca"
                       21        ="Puebla"
                       22        ="Quertaro"
                       23        ="Quintana Roo"
                       24        ="San Luis Potos"
                       25        ="Sinaloa"
                       26        ="Sonora"
                       27        ="Tabasco"
                       28        ="Tamaulipas"
                       29        ="Tlaxcala"
                       30        ="Veracruz"
                       31        ="Yucatn"
                       32        ="Zacatecas";
     VALUE id_modF     1         ="Urbanas Pblicas"
                       2         ="Rurales Pblicas"
                       3         ="Educacin Indgena"
                       4         ="Cursos Comunitarios"
                       5         ="Privadas"
                       6         ="Generales"
                       7         ="Tcnicas"
                       8         ="Telesecundarias"
                       9         ="Privadas";
     VALUE  $modF      "UP"      ="Urbanas Pblicas"
                       "RP"      ="Rurales Pblicas"
                       "EI"      ="Educacin Indgena"
                       "CC"      ="Cursos Comunitarios"
                       "UPV"     ="Privadas"
                       "GRAL"    ="Generales"
                       "TEC"     ="Tcnicas"
                       "TV"      ="Telesecundarias"
                       "PRIV"    ="Privadas";
     VALUE $entestdomF "999999"  ="Respuesta omitida";
     VALUE sexoF       1         ="Hombre"
                       2         ="Mujer"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE edadcF
                       1         ="Ocho aos o menos"
                       2         ="Nueve aos"
                       3         ="Diez aos"
                       4         ="Once aos o ms"
                       9         ="Respuesta omitida";
     VALUE edad1sF     1         ="Menos de Ocho aos"
                       2         ="Ocho aos"
                       3         ="Nueve aos"
                       4         ="Diez aos o ms"
                       9         ="Respuesta omitida";
     VALUE edadnF      1         ="Edad normativa"
                       2         ="Extra-edad"
                       9         ="Respuesta omitida";
     VALUE edad_acF    98        ="Respuesta mltiple"
                       99        ="Respuesta omitida";
     VALUE mes_nacF    1         ="Enero"
                       2         ="Febrero"
                       3         ="Marzo"
                       4         ="Abril"
                       5         ="Mayo"
                       6         ="Junio"
                       7         ="Julio"
                       8         ="Agosto"
                       9         ="Septiembre"
                       10        ="Octubre"
                       11        ="Noviembre"
                       12        ="Diciembre"
                       98        ="Respuesta mltiple"
                       99        ="Respuesta omitida";
     VALUE docenteF    99999     ="Respuesta omitida";
     VALUE RespF       0         ="Fallo"
                       1         ="Acierto"
                       5         ="Reactivo no alcanzado (se considera como no administrado)"
                       6         ="Fallo" /* Se consider como fallo(ilegible)*/
                       7         ="Reactivo no administrado"
                       9         ="Respuesta omitida";
RUN;



DATA INEE.Excale03_2006_Alum_Esc;
   LENGTH
       nacional           3
       escuela            4
       id_ent             3
       nom_ent            $20
       id_mod             3
       mod                $4
       entest             $6
       entestdom          $6
       alumno             6
       id_instr           $16
       sexo               3
       edad               8
       edadc              3
       edad1sep           8
       edad1sepc          3
       edadn              3
       edad_ac            3
       mes_nac            3
       w_alu              8
       docente            5
       pre1_01            3
       pre3_03            3
       pre3_04            3
       pre3_05            3
       pre3_06            3
       pre3_07            3
       pre3_08            3
       pre3_09            3
       pre3_10            3
       pre3_11            3
       pre3_12            3
       pre4_13            3
       pre4_14            3
       pre4_15            3
       pre4_16            3
       pre4_17            3
       pre4_18            3
       pre4_19            3
       pre4_20            3
       pre4_21            3
       pre5_22            3
       pre5_23            3
       pre5_24            3
       pre5_25            3
       pre5_26            3
       pre5_27            3
       pre5_28            3
       pre5_29            3
       pre5_30            3
       pre5_31            3
       pre_orto           3
       prs6_01            3
       prs6_02            3
       prs6_03            3
       prs6_04            3
       prs7_05            3
       pv1RA              8
       pv2RA              8
       pv3RA              8
       pv4RA              8
       pv5RA              8
       RAnvl1             3
       RAnvl2             3
       RAnvl3             3
       RAnvl4             3
       RAnvl5             3
       RAnvlb1            3
       RAnvlb2            3
       RAnvlb3            3
       RAnvlb4            3
       RAnvlb5            3
       wvarstrr           3
       w_fstr1            8
       w_fstr2            8
       w_fstr3            8
       w_fstr4            8
       w_fstr5            8
       w_fstr6            8
       w_fstr7            8
       w_fstr8            8
       w_fstr9            8
       w_fstr10           8
       w_fstr11           8
       w_fstr12           8
       w_fstr13           8
       w_fstr14           8
       w_fstr15           8
       w_fstr16           8
       w_fstr17           8
       w_fstr18           8
       w_fstr19           8
       w_fstr20           8
       w_fstr21           8
       w_fstr22           8
       w_fstr23           8
       w_fstr24           8
       w_fstr25           8
       w_fstr26           8
       w_fstr27           8
       w_fstr28           8
       w_fstr29           8
       w_fstr30           8
       w_fstr31           8
       w_fstr32           8
       w_fstr33           8
       w_fstr34           8
       w_fstr35           8
       w_fstr36           8
       w_fstr37           8
       w_fstr38           8
       w_fstr39           8
       w_fstr40           8
       w_fstr41           8
       w_fstr42           8
       w_fstr43           8
       w_fstr44           8
       w_fstr45           8
       w_fstr46           8
       w_fstr47           8
       w_fstr48           8
       w_fstr49           8
       w_fstr50           8
       w_fstr51           8
       w_fstr52           8
       w_fstr53           8
       w_fstr54           8
       w_fstr55           8
       w_fstr56           8
       w_fstr57           8
       w_fstr58           8
       w_fstr59           8
       w_fstr60           8
       w_fstr61           8
       w_fstr62           8
       w_fstr63           8
       w_fstr64           8
       w_fstr65           8
       w_fstr66           8
       w_fstr67           8
       w_fstr68           8
       w_fstr69           8
       w_fstr70           8
       w_fstr71           8
       w_fstr72           8
       w_fstr73           8
       w_fstr74           8
       w_fstr75           8
       w_fstr76           8
       w_fstr77           8
       w_fstr78           8
       w_fstr79           8
       w_fstr80           8
   ;

INFILE alum MISSOVER LINESIZE = 1368;
   INPUT
       nacional               1 - 1
       escuela                2 - 5
       id_ent                 6 - 7
       nom_ent                8 - 27
       id_mod                28 - 28
       mod                   29 - 32
       entest                33 - 38
       entestdom             39 - 44
       alumno                45 - 50
       id_instr              51 - 66
       sexo                  67 - 67
       EDAD                  68 - 72
       EDADC                 73 - 73
       edad1sep              74 - 89
       edad1sepc             90 - 92
       EDADN                 93 - 93
       edad_ac               94 - 95
       mes_nac               96 - 97
       w_alu                 98 - 113
       docente              114 - 118
       pre1_01              119 - 119
       pre3_03              120 - 120
       pre3_04              121 - 121
       pre3_05              122 - 122
       pre3_06              123 - 123
       pre3_07              124 - 124
       pre3_08              125 - 125
       pre3_09              126 - 126
       pre3_10              127 - 127
       pre3_11              128 - 128
       pre3_12              129 - 129
       pre4_13              130 - 130
       pre4_14              131 - 131
       pre4_15              132 - 132
       pre4_16              133 - 133
       pre4_17              134 - 134
       pre4_18              135 - 135
       pre4_19              136 - 136
       pre4_20              137 - 137
       pre4_21              138 - 138
       pre5_22              139 - 139
       pre5_23              140 - 140
       pre5_24              141 - 141
       pre5_25              142 - 142
       pre5_26              143 - 143
       pre5_27              144 - 144
       pre5_28              145 - 145
       pre5_29              146 - 146
       pre5_30              147 - 147
       pre5_31              148 - 148
       pre_orto             149 - 151
       prs6_01              152 - 152
       prs6_02              153 - 153
       prs6_03              154 - 154
       prs6_04              155 - 155
       prs7_05              156 - 156
       pv1RA                157 - 172
       pv2RA                173 - 188
       pv3RA                189 - 204
       pv4RA                205 - 220
       pv5RA                221 - 236
       RAnvl1               237 - 237
       RAnvl2               238 - 238
       RAnvl3               239 - 239
       RAnvl4               240 - 240
       RAnvl5               241 - 241
       RAnvlb1              242 - 242
       RAnvlb2              243 - 243
       RAnvlb3              244 - 244
       RAnvlb4              245 - 245
       RAnvlb5              246 - 246
       wvarstrr             247 - 248
       w_fstr1              249 - 262
       w_fstr2              263 - 276
       w_fstr3              277 - 290
       w_fstr4              291 - 304
       w_fstr5              305 - 318
       w_fstr6              319 - 332
       w_fstr7              333 - 346
       w_fstr8              347 - 360
       w_fstr9              361 - 374
       w_fstr10             375 - 388
       w_fstr11             389 - 402
       w_fstr12             403 - 416
       w_fstr13             417 - 430
       w_fstr14             431 - 444
       w_fstr15             445 - 458
       w_fstr16             459 - 472
       w_fstr17             473 - 486
       w_fstr18             487 - 500
       w_fstr19             501 - 514
       w_fstr20             515 - 528
       w_fstr21             529 - 542
       w_fstr22             543 - 556
       w_fstr23             557 - 570
       w_fstr24             571 - 584
       w_fstr25             585 - 598
       w_fstr26             599 - 612
       w_fstr27             613 - 626
       w_fstr28             627 - 640
       w_fstr29             641 - 654
       w_fstr30             655 - 668
       w_fstr31             669 - 682
       w_fstr32             683 - 696
       w_fstr33             697 - 710
       w_fstr34             711 - 724
       w_fstr35             725 - 738
       w_fstr36             739 - 752
       w_fstr37             753 - 766
       w_fstr38             767 - 780
       w_fstr39             781 - 794
       w_fstr40             795 - 808
       w_fstr41             809 - 822
       w_fstr42             823 - 836
       w_fstr43             837 - 850
       w_fstr44             851 - 864
       w_fstr45             865 - 878
       w_fstr46             879 - 892
       w_fstr47             893 - 906
       w_fstr48             907 - 920
       w_fstr49             921 - 934
       w_fstr50             935 - 948
       w_fstr51             949 - 962
       w_fstr52             963 - 976
       w_fstr53             977 - 990
       w_fstr54             991 - 1004
       w_fstr55            1005 - 1018
       w_fstr56            1019 - 1032
       w_fstr57            1033 - 1046
       w_fstr58            1047 - 1060
       w_fstr59            1061 - 1074
       w_fstr60            1075 - 1088
       w_fstr61            1089 - 1102
       w_fstr62            1103 - 1116
       w_fstr63            1117 - 1130
       w_fstr64            1131 - 1144
       w_fstr65            1145 - 1158
       w_fstr66            1159 - 1172
       w_fstr67            1173 - 1186
       w_fstr68            1187 - 1200
       w_fstr69            1201 - 1214
       w_fstr70            1215 - 1228
       w_fstr71            1229 - 1242
       w_fstr72            1243 - 1256
       w_fstr73            1257 - 1270
       w_fstr74            1271 - 1284
       w_fstr75            1285 - 1298
       w_fstr76            1299 - 1312
       w_fstr77            1313 - 1326
       w_fstr78            1327 - 1340
       w_fstr79            1341 - 1354
       w_fstr80            1355 - 1368
   ;

   LABEL
       nacional    = "Variable auxiliar para obtener promedios nacionales"
       escuela     = "Identificador de la escuela"
       id_ent      = "Entidad federativa (identificador numrico)"
       nom_ent     = "Entidad federativa"
       id_mod      = "Estrato escolar o Modalidad educativa (identificador numrico)"
       mod         = "Estrato escolar o Modalidad educativa"
       entest      = "Estratos del diseo muestral con el que se estiman los parmetros y errores estndar (Entidad federativa-Modalidad)"
       entestdom   = "Variable auxiliar para identificar los dominios de estudio (subpoblaciones donde se reportan resultados) a nivel de modalidad al interior de las entidades"
       alumno      = "Identifcador del alumno"
       id_instr    = "Identificador del cuadernillo de examen"
       sexo        = "Sexo del alumno"
       edad        = "Edad del alumno al mes de mayo de 2006, en aos (al momento de la aplicacin)"
       edadc       = "Edad del alumno al mes de mayo de 2006, codificada (al momento de la aplicacin)"
       edad1sep    = "Edad del alumno al mes de septiembre de 2005, en aos (al inicio del ciclo escolar)"
       edad1sepc   = "Edad del alumno al mes de septiembre de 2005, codificada (al inicio del ciclo escolar)"
       edadn       = "Edad normativa"
       edad_ac     = "Edad en aos cumplidos (al momento de la aplicacin)"
       mes_nac     = "Mes de nacimiento del alumno (al momento de la aplicacin)"
       w_alu       = "Peso muestral o ponderador del alumno"
       docente     = "Identificador del docente que imparte clases al alumno"
       pre1_01     = "Reactivo PRE1_01. Escribir cinco elementos de un campo semntico"
       pre3_03     = "Reactivo PRE3_03. Escribir una secuencia descriptiva mediante el uso de oraciones atributivas"
       pre3_04     = "Reactivo PRE3_04. Usar ideas en forma original en descripcin"
       pre3_05     = "Reactivo PRE3_05. Emplear oraciones con sentido completo en textos descriptivos"
       pre3_06     = "Reactivo PRE3_06. Usar oracin temtica para organizar ideas"
       pre3_07     = "Reactivo PRE3_07. Usar elementos de cohesin en textos descriptivos"
       pre3_08     = "Reactivo PRE3_08. Organizar un texto descriptivo de manera coherente"
       pre3_09     = "Reactivo PRE3_09. Utilizar palabras o expresiones que describan"
       pre3_10     = "Reactivo PRE3_10. Respetar la concordancia entre gnero, nmero y tiempo verbal en textos descriptivos"
       pre3_11     = "Reactivo PRE3_11. Utilizar puntuacin convencional en textos descriptivos"
       pre3_12     = "Reactivo PRE3_12. Respetar la segmentacin convencional de las palabras en textos descriptivos"
       pre4_13     = "Reactivo PRE4_13. Escribir un recado"
       pre4_14     = "Reactivo PRE4_14. Usar ideas en forma original en el recado"
       pre4_15     = "Reactivo PRE4_15. Emplear oraciones con sentido completo en recado"
       pre4_16     = "Reactivo PRE4_16. Usar elementos de cohesin en recado"
       pre4_17     = "Reactivo PRE4_17. Organizar la informacin del recado de manera coherente"
       pre4_18     = "Reactivo PRE4_18. Utilizar el formato adecuado para recado"
       pre4_19     = "Reactivo PRE4_19. Respetar la concordancia entre gnero, nmero y tiempo verbal en recado"
       pre4_20     = "Reactivo PRE4_20. Utilizar puntuacin convencional en los recados"
       pre4_21     = "Reactivo PRE4_21. Respetar la segmentacin convencional de las palabras en recado"
       pre5_22     = "Reactivo PRE5_22. Escribir una secuencia narrativa con principio, desarrollo y final"
       pre5_23     = "Reactivo PRE5_23. Introducir dilogos directos o indirectos en textos narrativos"
       pre5_24     = "Reactivo PRE5_24. Describir personajes o espacio en textos narrativos"
       pre5_25     = "Reactivo PRE5_25. Introducir un final creativo y coherente con la narracin"
       pre5_26     = "Reactivo PRE5_26. Emplear oraciones con sentido completo en textos narrativos"
       pre5_27     = "Reactivo PRE5_27. Usar elementos de cohesin en secuencia narrativa"
       pre5_28     = "Reactivo PRE5_28. Dar coherencia a una secuencia narrativa"
       pre5_29     = "Reactivo PRE5_29. Respetar la concordancia entre gnero, nmero y tiempo verbal en textos narrativos"
       pre5_30     = "Reactivo PRE5_30. Utilizar puntuacin convencional en  textos narrativos"
       pre5_31     = "Reactivo PRE5_31. Respetar la segmentacin convencional de las palabras en textos narrativos"
       pre_orto    = "Reactivo PRE_ORTO. "
       prs6_01     = "Reactivo PRS6_01. Ubicar en un mapa de Mxico su entidad"
       prs6_02     = "Reactivo PRS6_02. Escribir el nombre de su entidad"
       prs6_03     = "Reactivo PRS6_03. Ubicar las colindancias geogrficas de su entidad"
       prs6_04     = "Reactivo PRS6_04. Escribir el nombre de alguna fiesta tradicional de su entidad"
       prs7_05     = "Reactivo PRS7_05. Escribir el nombre o sigla de algn partido poltico registrado ante el IFE"
       pv1ra       = "Primer valor plausible de Escritura"
       pv2ra       = "Segundo valor plausible de Escritura"
       pv3ra       = "Tercer valor plausible de Escritura"
       pv4ra       = "Cuarto valor plausible de Escritura"
       pv5ra       = "Quinto valor plausible de Escritura"
       ranvl1      = "Nivel de logro en Escritura. Asociado a pv1ra. (Cuatro niveles)"
       ranvl2      = "Nivel de logro en Escritura. Asociado a pv2ra. (Cuatro niveles)"
       ranvl3      = "Nivel de logro en Escritura. Asociado a pv3ra. (Cuatro niveles)"
       ranvl4      = "Nivel de logro en Escritura. Asociado a pv4ra. (Cuatro niveles)"
       ranvl5      = "Nivel de logro en Escritura. Asociado a pv5ra. (Cuatro niveles)"
       ranvlb1     = "Identifica si el alumno pertenece al menos al nivel bsico de logro en Escritura. Asociado a pv1ra."
       ranvlb2     = "Identifica si el alumno pertenece al menos al nivel bsico de logro en Escritura. Asociado a pv2ra."
       ranvlb3     = "Identifica si el alumno pertenece al menos al nivel bsico de logro en Escritura. Asociado a pv3ra."
       ranvlb4     = "Identifica si el alumno pertenece al menos al nivel bsico de logro en Escritura. Asociado a pv4ra."
       ranvlb5     = "Identifica si el alumno pertenece al menos al nivel bsico de logro en Escritura. Asociado a pv5ra."
       wvarstrr    = "Identificador del pseudoestrato (1 a 80) definido para el clculo de errores estndar con el mtodo de remuestreo BRR"
       w_fstr1     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr2     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr3     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr4     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr5     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr6     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr7     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr8     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr9     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr10    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr11    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr12    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr13    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr14    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr15    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr16    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr17    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr18    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr19    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr20    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr21    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr22    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr23    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr24    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr25    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr26    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr27    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr28    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr29    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr30    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr31    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr32    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr33    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr34    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr35    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr36    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr37    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr38    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr39    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr40    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr41    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr42    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr43    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr44    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr45    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr46    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr47    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr48    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr49    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr50    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr51    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr52    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr53    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr54    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr55    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr56    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr57    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr58    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr59    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr60    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr61    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr62    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr63    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr64    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr65    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr66    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr67    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr68    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr69    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr70    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr71    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr72    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr73    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr74    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr75    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr76    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr77    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr78    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr79    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr80    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
   ;

   FORMAT
       nacional           1.
       escuela            4.
       id_ent             id_entF.
       nom_ent            $char20.
       id_mod             id_modF.
       mod                $modF.
       entest             $char6.
       entestdom          $entestdomF.
       alumno             6.
       id_instr           $char16.
       sexo               sexoF.
       edadc              edadcF.
       edad1sepc          edad1sF.
       edadn              edadnF.
       edad_ac            edad_acF.
       mes_nac            mes_nacF.
       docente            docenteF.
       pre1_01            RespF.
       pre3_03            RespF.
       pre3_04            RespF.
       pre3_05            RespF.
       pre3_06            RespF.
       pre3_07            RespF.
       pre3_08            RespF.
       pre3_09            RespF.
       pre3_10            RespF.
       pre3_11            RespF.
       pre3_12            RespF.
       pre4_13            RespF.
       pre4_14            RespF.
       pre4_15            RespF.
       pre4_16            RespF.
       pre4_17            RespF.
       pre4_18            RespF.
       pre4_19            RespF.
       pre4_20            RespF.
       pre4_21            RespF.
       pre5_22            RespF.
       pre5_23            RespF.
       pre5_24            RespF.
       pre5_25            RespF.
       pre5_26            RespF.
       pre5_27            RespF.
       pre5_28            RespF.
       pre5_29            RespF.
       pre5_30            RespF.
       pre5_31            RespF.
       prs6_01            RespF.
       prs6_02            RespF.
       prs6_03            RespF.
       prs6_04            RespF.
       prs7_05            RespF.
       ranvl1             1.
       ranvl2             1.
       ranvl3             1.
       ranvl4             1.
       ranvl5             1.
       ranvlb1            1.
       ranvlb2            1.
       ranvlb3            1.
       ranvlb4            1.
       ranvlb5            1.
       wvarstrr           2.
   ;

/**************************************************************************
/*  Definicin de valores perdidos
/*   .N o N = No Administrado o no alcanzado.
/*   .M o M = Respuesta Multiple.
/*   .S o S = No contestado.
/*************************************************************************/
   IF entestdom = "999999"  THEN entestdom = "S";
   IF  sexo = 8 THEN  sexo = .M;
   IF  edad_ac = 98 THEN  edad_ac = .M;
   IF  mes_nac = 98 THEN  mes_nac = .M;

   ARRAY perdidos1(4)  sexo edadc edad1sepc edadn;
   DO  i=1 TO 4;
         IF perdidos1{i}=9 THEN  perdidos1{i}= .S;
   END;

   ARRAY perdidos2(4)  edad edad1sep edad_ac mes_nac;
   DO  i=1 TO 4;
         IF perdidos2{i}=99 THEN  perdidos2{i}= .S;
   END;

   IF  pre_orto = 999 THEN  pre_orto = .S;

   IF  docente = 99999 THEN  docente = .S;

   ARRAY perdidos3(35)
                   pre1_01 pre3_03 pre3_04 pre3_05 pre3_06 pre3_07 pre3_08
                   pre3_09 pre3_10 pre3_11 pre3_12 pre4_13 pre4_14 pre4_15
                   pre4_16 pre4_17 pre4_18 pre4_19 pre4_20 pre4_21 pre5_22
                   pre5_23 pre5_24 pre5_25 pre5_26 pre5_27 pre5_28 pre5_29
                   pre5_30 pre5_31 prs6_01 prs6_02 prs6_03 prs6_04 prs7_05;
   DO  i=1 TO 35;
          IF (perdidos3{i} = 5 OR  perdidos3{i} = 7)  THEN  perdidos3{i} = .N;
		  IF  perdidos3{i} = 9  THEN  perdidos3{i} = .S;
   END;

   drop i;
RUN;
